@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.71 2005/04/11 17:38:33 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.74 2005/09/15 16:45:27 richb Exp $
  *
  *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -123,6 +123,7 @@ enum trig_func {SIN=0, COS=1, TAN=2};
 #define KEY_RSFT  s_buttons[1]              /* > */
 #define KEY_16    s_buttons[2]              /* [ */
 #define KEY_32    s_buttons[3]              /* ] */
+#define KEY_MOD   s_buttons[6]              /* M */
 #define KEY_ACC   s_buttons[7]              /* A */
 
 #define KEY_CON   s_buttons[8]              /* # */
@@ -362,6 +363,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int show_zeroes;   /* Set if trailing zeroes should be shown. */
     int started;       /* Set just before window is displayed. */
     int toclear;       /* Indicates if display should be cleared. */
+    int warn_change_mode;    /* Should we warn user when changing modes? */
 };
 
 typedef struct calcVars *Vars;
@@ -449,7 +451,7 @@ void make_reg(int, char *);
 void make_registers();
 void mperr();
 void MPstr_to_num(char *, enum base_type, int *);
-void paren_disp(char);
+void paren_disp(int);
 void process_item(struct button *);
 void process_str(char *);
 void push_num(int *);
@@ -471,6 +473,7 @@ void set_ins_key();
 void set_inv_item(int);
 void set_mode(enum mode_type);
 void set_title(enum fcp_type, char *);
+void show_change_mode_dialog();
 void show_display(int *);
 void show_error(char *);
 void show_menu();
